@@ -21,8 +21,8 @@ use Exporter;
 
 ## ----------------------------------------------------------------------
 ## get command line options
-use vars qw( $opt_L $opt_P $opt_b $opt_c $opt_e $opt_f $opt_l $opt_m $opt_t $opt_1 $opt_x $opt_X);
-getopts( 'LPb:ce:f:l:mt:1xX:' );
+use vars qw( $opt_L $opt_P $opt_b $opt_c $opt_C $opt_e $opt_f $opt_l $opt_m $opt_t $opt_1 $opt_x $opt_X);
+getopts( 'LPb:cCe:f:l:mt:1xX:' );
 
 ## ----------------------------------------------------------------------
 ## import packages
