@@ -55,6 +55,12 @@ if ( $DebianDoc_SGML::Format::Driver::opt_c )
 	    && $DebianDoc_SGML::Format::Driver::locale =~ m/\./;
     $content = ".$language_tag$charset";
 }
+if ( $DebianDoc_SGML::Format::Driver::opt_C )
+{
+    my $language_tag = lc( locale2language_tag( $DebianDoc_SGML::Format::Driver::opt_l ) );
+    $language_tag = 'en' if $language_tag eq undef;
+    $content = ".$language_tag";
+}
 my $basename = $DebianDoc_SGML::Format::Driver::opt_b;
 my $prefix = '';
 if ( $DebianDoc_SGML::Format::Driver::opt_b =~ m,/, )
